@@ -1,6 +1,6 @@
 # Copyright (C) 2014,2015 VA Linux Systems Japan K.K.
 # Copyright (C) 2014,2015 YAMAMOTO Takashi <yamamoto at valinux co jp>
-# Copyright (C) 2014,2015 Fumihiko Kakuma <kakuma at valinux co jp>
+# Copyright (C) 2014 Fumihiko Kakuma <kakuma at valinux co jp>
 # All Rights Reserved.
 #
 # Based on openvswitch agent.
@@ -23,10 +23,7 @@
 import time
 
 from oslo_config import cfg
-from oslo_log import helpers as log_helpers
-from oslo_log import log as logging
 import oslo_messaging
-from oslo_service import loopingcall
 from ryu.app.ofctl import api as ryu_api
 from ryu.base import app_manager
 import ryu.cfg as ryu_cfg
@@ -34,25 +31,26 @@ from ryu.controller import handler
 from ryu.controller import ofp_event
 from ryu.lib import hub
 from ryu.ofproto import ofproto_v1_3 as ryu_ofp13
-import six
 
-from neutron.agent.common import ovs_lib
+from neutron.agent import l2population_rpc
 from neutron.agent.linux import ip_lib
+from neutron.agent.linux import ovs_lib
 from neutron.agent import rpc as agent_rpc
 from neutron.agent import securitygroups_rpc as sg_rpc
 from neutron.common import constants as n_const
+from neutron.common import log
 from neutron.common import topics
 from neutron.common import utils as n_utils
 from neutron import context
+from neutron.openstack.common import log as logging
+from neutron.openstack.common import loopingcall
 from neutron.plugins.common import constants as p_const
-from neutron.plugins.ml2.drivers.l2pop.rpc_manager import l2population_rpc
-from neutron.plugins.ml2.drivers.openvswitch.agent.common import constants
+from neutron.plugins.openvswitch.common import constants
 
 from networking_ofagent.i18n import _LE, _LI, _LW
 from networking_ofagent.plugins.ofagent.agent import arp_lib
 from networking_ofagent.plugins.ofagent.agent import constants as ofa_const
 from networking_ofagent.plugins.ofagent.agent import flows
-from networking_ofagent.plugins.ofagent.agent import monitor
 from networking_ofagent.plugins.ofagent.agent import ports
 from networking_ofagent.plugins.ofagent.agent import tables
 
@@ -67,7 +65,7 @@ cfg.CONF.import_group('AGENT',
 class LocalVLANMapping(object):
     def __init__(self, vlan, network_type, physical_network, segmentation_id,
                  vif_ports=None):
-        assert(isinstance(vlan, six.integer_types))
+        assert(isinstance(vlan, (int, long)))
         if vif_ports is None:
             vif_ports = {}
         self.vlan = vlan
@@ -136,7 +134,6 @@ class OFANeutronAgentRyuApp(app_manager.RyuApp):
     def __init__(self, *args, **kwargs):
         super(OFANeutronAgentRyuApp, self).__init__(*args, **kwargs)
         self.arplib = arp_lib.ArpLib(self)
-        self.monitor = monitor.PortMonitor()
 
     def start(self):
         super(OFANeutronAgentRyuApp, self).start()
@@ -169,13 +166,6 @@ class OFANeutronAgentRyuApp(app_manager.RyuApp):
     def del_arp_table_entry(self, network, ip):
         self.arplib.del_arp_table_entry(network, ip)
 
-    @handler.set_ev_cls(ofp_event.EventOFPPortStatus, handler.MAIN_DISPATCHER)
-    def _port_status_handler(self, ev):
-        self.monitor.port_status_handler(ev)
-
-    def get_port_status_list(self):
-        return self.monitor.get_port_status_list()
-
 
 class OFANeutronAgent(sg_rpc.SecurityGroupAgentRpcCallbackMixin,
                       l2population_rpc.L2populationRpcCallBackTunnelMixin):
@@ -192,8 +182,7 @@ class OFANeutronAgent(sg_rpc.SecurityGroupAgentRpcCallbackMixin,
     # history
     #   1.0 Initial version
     #   1.1 Support Security Group RPC
-    #   1.3 Added param devices_to_update to security_groups_provider_updated
-    target = oslo_messaging.Target(version='1.3')
+    target = oslo_messaging.Target(version='1.1')
 
     def __init__(self, ryuapp, integ_br, local_ip,
                  bridge_mappings, interface_mappings,
@@ -215,8 +204,8 @@ class OFANeutronAgent(sg_rpc.SecurityGroupAgentRpcCallbackMixin,
         super(OFANeutronAgent, self).__init__()
         self.ryuapp = ryuapp
         # TODO(yamamoto): Remove this VLAN leftover
-        self.available_local_vlans = set(range(ofa_const.LOCAL_VLAN_MIN,
-                                               ofa_const.LOCAL_VLAN_MAX))
+        self.available_local_vlans = set(xrange(ofa_const.LOCAL_VLAN_MIN,
+                                                ofa_const.LOCAL_VLAN_MAX))
         self.tunnel_types = tunnel_types or []
         l2pop_network_types = list(set(self.tunnel_types +
                                        [p_const.TYPE_VLAN,
@@ -242,16 +231,16 @@ class OFANeutronAgent(sg_rpc.SecurityGroupAgentRpcCallbackMixin,
         self.int_br = Bridge(integ_br, self.ryuapp)
         # Stores port update notifications for processing in main loop
         self.updated_ports = set()
-        self.int_ofports = {}
-        self.local_vlan_map = {}
-        self.tun_ofports = {}  # network_type -> tunnel ofport
-        self.local_ip = local_ip
         self.setup_rpc()
         self.setup_integration_br()
+        self.int_ofports = {}
         self.setup_physical_interfaces(interface_mappings)
-
+        self.local_vlan_map = {}
+        self.tun_ofports = {}  # network_type -> tunnel ofport
         self.polling_interval = polling_interval
+
         self.enable_tunneling = bool(self.tunnel_types)
+        self.local_ip = local_ip
         self.tunnel_count = 0
         self.vxlan_udp_port = cfg.CONF.AGENT.vxlan_udp_port
         self.dont_fragment = cfg.CONF.AGENT.dont_fragment
@@ -301,20 +290,6 @@ class OFANeutronAgent(sg_rpc.SecurityGroupAgentRpcCallbackMixin,
                 self._report_state)
             heartbeat.start(interval=report_interval)
 
-    def _send_set_async(self, br):
-        """Set asynchronous configuration message for the given bridge."""
-        datapath = br.datapath
-        ofp = datapath.ofproto
-        ofpp = datapath.ofproto_parser
-        packet_in_mask = 1 << ofp.OFPR_ACTION | 1 << ofp.OFPR_INVALID_TTL
-        port_status_mask = 1 << ofp.OFPPR_DELETE
-        flow_removed_mask = 0
-        msg = ofpp.OFPSetAsync(datapath,
-                               [packet_in_mask, 0],
-                               [port_status_mask, 0],
-                               [flow_removed_mask, 0])
-        ryu_api.send_msg(app=self.ryuapp, msg=msg)
-
     def _get_ports(self, br):
         """Generate ports.Port instances for the given bridge."""
         datapath = br.datapath
@@ -333,11 +308,11 @@ class OFANeutronAgent(sg_rpc.SecurityGroupAgentRpcCallbackMixin,
                    self._get_ports(br) if p.is_neutron_port())
 
     def get_net_uuid(self, vif_id):
-        for network_id, vlan_mapping in self.local_vlan_map.items():
+        for network_id, vlan_mapping in self.local_vlan_map.iteritems():
             if vif_id in vlan_mapping.vif_ports:
                 return network_id
 
-    @log_helpers.log_method_call
+    @log.log
     def port_update(self, context, **kwargs):
         port = kwargs.get('port')
         # Put the port identifier in the updated_ports set.
@@ -349,7 +324,7 @@ class OFANeutronAgent(sg_rpc.SecurityGroupAgentRpcCallbackMixin,
     def _tunnel_port_lookup(self, network_type, _remote_ip):
         return self.tun_ofports.get(network_type)
 
-    @log_helpers.log_method_call
+    @log.log
     def fdb_add(self, context, fdb_entries):
         for lvm, agent_ports in self.get_agent_ports(fdb_entries,
                                                      self.local_vlan_map):
@@ -363,7 +338,7 @@ class OFANeutronAgent(sg_rpc.SecurityGroupAgentRpcCallbackMixin,
             else:
                 self._fdb_add_arp(lvm, agent_ports)
 
-    @log_helpers.log_method_call
+    @log.log
     def fdb_remove(self, context, fdb_entries):
         for lvm, agent_ports in self.get_agent_ports(fdb_entries,
                                                      self.local_vlan_map):
@@ -377,7 +352,7 @@ class OFANeutronAgent(sg_rpc.SecurityGroupAgentRpcCallbackMixin,
             else:
                 self._fdb_remove_arp(lvm, agent_ports)
 
-    @log_helpers.log_method_call
+    @log.log
     def _fdb_add_arp(self, lvm, agent_ports):
         for _remote_ip, port_infos in agent_ports.items():
             for port_info in port_infos:
@@ -387,7 +362,7 @@ class OFANeutronAgent(sg_rpc.SecurityGroupAgentRpcCallbackMixin,
                                                 port_info.ip_address,
                                                 port_info.mac_address)
 
-    @log_helpers.log_method_call
+    @log.log
     def _fdb_remove_arp(self, lvm, agent_ports):
         for _remote_ip, port_infos in agent_ports.items():
             for port_info in port_infos:
@@ -441,7 +416,7 @@ class OFANeutronAgent(sg_rpc.SecurityGroupAgentRpcCallbackMixin,
         elif action == 'remove':
             self.ryuapp.del_arp_table_entry(local_vid, ip_address)
 
-    @log_helpers.log_method_call
+    @log.log
     def _fdb_chg_ip(self, context, fdb_entries):
         self.fdb_chg_ip_tun(context, self.int_br, fdb_entries, self.local_ip,
                             self.local_vlan_map)
@@ -612,7 +587,6 @@ class OFANeutronAgent(sg_rpc.SecurityGroupAgentRpcCallbackMixin,
         br = self.int_br
         br.setup_ofp()
         br.setup_default_table()
-        self._send_set_async(br)
 
     def setup_physical_interfaces(self, interface_mappings):
         """Setup the physical network interfaces.
@@ -622,7 +596,7 @@ class OFANeutronAgent(sg_rpc.SecurityGroupAgentRpcCallbackMixin,
         :param interface_mappings: map physical network names to
                                    interface names.
         """
-        for physical_network, interface_name in interface_mappings.items():
+        for physical_network, interface_name in interface_mappings.iteritems():
             ofport = int(self.int_br.add_port(interface_name))
             self.int_ofports[physical_network] = ofport
 
@@ -650,31 +624,6 @@ class OFANeutronAgent(sg_rpc.SecurityGroupAgentRpcCallbackMixin,
         port_info['removed'] = registered_ports - cur_ports
         return port_info
 
-    def _check_port_status_list(self, port_status_list, port_info):
-        """Checks if port_status_list has port-no changed ports.
-
-        Checks if there are ports which port-no change occurred in
-        list of port status messages and returns them. And adds target
-        ports to an updated set in port_info.
-
-        :param port_status_list: list of port delete status messages
-        :param port_info: dict has set of current and updated port names
-        """
-        # Currently port_status_list has only delete status messages.
-        check_ports = dict((ps.name, ps) for ps in port_status_list
-            if ps.name in port_info['current'])
-        check_ports_set = set(check_ports.keys())
-        LOG.debug("Agent daemon_loop check_ports: %(check_ports)s "
-                  "check_ports_set: %(check_ports_set)s",
-                  {'check_ports': check_ports,
-                   'check_ports_set': check_ports_set})
-        if check_ports_set:
-            if 'updated' in port_info:
-                port_info['updated'] |= check_ports_set
-            else:
-                port_info['updated'] = check_ports_set
-        return check_ports
-
     def treat_vif_port(self, vif_port, port_id, network_id, network_type,
                        physical_network, segmentation_id, admin_state_up):
         if vif_port:
@@ -732,19 +681,7 @@ class OFANeutronAgent(sg_rpc.SecurityGroupAgentRpcCallbackMixin,
         # We only have one port per network_type.
         pass
 
-    @log_helpers.log_method_call
-    def _repair_ofport_change(self, port, net_uuid):
-        if net_uuid not in self.local_vlan_map:
-            LOG.info(_LI("_repair_ofport_change() net_uuid %s not in "
-                         "local_vlan_map"), net_uuid)
-            return
-        lvm = self.local_vlan_map[net_uuid]
-        self.int_br.check_in_port_delete_port(port.ofport)
-        if port.vif_mac is None:
-            return
-        self.int_br.local_out_delete_port(lvm.vlan, port.vif_mac)
-
-    def treat_devices_added_or_updated(self, devices, check_ports):
+    def treat_devices_added_or_updated(self, devices):
         resync = False
         all_ports = dict((p.normalized_port_name(), p) for p in
                          self._get_ports(self.int_br) if p.is_neutron_port())
@@ -767,19 +704,6 @@ class OFANeutronAgent(sg_rpc.SecurityGroupAgentRpcCallbackMixin,
                           {'device': device, 'e': e})
                 resync = True
                 continue
-            if device in check_ports:
-                ps = check_ports[device]
-                if port.ofport != ps.port.ofport:
-                    ps.port.vif_mac = details.get('mac_address')
-                    LOG.debug("Repair ofport changed old port "
-                              "ofport: %(ofport)s vif_mac: %(mac)s",
-                              {'ofport': ps.port.ofport,
-                               'mac': ps.port.vif_mac})
-                    LOG.debug("Repair ofport changed new port "
-                              "ofport: %(ofport)s vif_mac: %(mac)s",
-                              {'ofport': port.ofport,
-                               'mac': port.vif_mac})
-                    self._repair_ofport_change(ps.port, details['network_id'])
             if 'port_id' in details:
                 LOG.info(_LI("Port %(device)s updated. Details: %(details)s"),
                          {'device': device, 'details': details})
@@ -825,7 +749,7 @@ class OFANeutronAgent(sg_rpc.SecurityGroupAgentRpcCallbackMixin,
             self.port_unbound(device)
         return resync
 
-    def process_network_ports(self, port_info, check_ports):
+    def process_network_ports(self, port_info):
         resync_add = False
         resync_removed = False
         # If there is an exception while processing security groups ports
@@ -842,7 +766,7 @@ class OFANeutronAgent(sg_rpc.SecurityGroupAgentRpcCallbackMixin,
         if devices_added_updated:
             start = time.time()
             resync_add = self.treat_devices_added_or_updated(
-                devices_added_updated, check_ports)
+                devices_added_updated)
             LOG.debug("process_network_ports - iteration:%(iter_num)d - "
                       "treat_devices_added_or_updated completed "
                       "in %(elapsed).3f",
@@ -914,10 +838,6 @@ class OFANeutronAgent(sg_rpc.SecurityGroupAgentRpcCallbackMixin,
                 self.updated_ports = set()
                 port_info = self.scan_ports(ports, updated_ports_copy)
                 ports = port_info['current']
-                # In the following calling port_info may be updated
-                port_status_list = self.ryuapp.get_port_status_list()
-                check_ports = self._check_port_status_list(port_status_list,
-                                                           port_info)
                 LOG.debug("Agent daemon_loop - iteration:%(iter_num)d - "
                           "port information retrieved. "
                           "Elapsed:%(elapsed).3f",
@@ -930,7 +850,7 @@ class OFANeutronAgent(sg_rpc.SecurityGroupAgentRpcCallbackMixin,
                     LOG.debug("Starting to process devices in:%s",
                               port_info)
                     # If treat devices fails - must resync with plugin
-                    sync = self.process_network_ports(port_info, check_ports)
+                    sync = self.process_network_ports(port_info)
                     LOG.debug("Agent daemon_loop - "
                               "iteration:%(iter_num)d - "
                               "ports processed. Elapsed:%(elapsed).3f",
